@@ -239,9 +239,11 @@
 "XVkbd*deadkey_panel*dead_doubleacute.label: \\264\\264",
 "XVkbd*deadkey_panel*dead_tilde.label: ~",
 "XVkbd*deadkey_panel*dead_abovedot.label: \\267",
-"XVkbd.customizations: default,belgian,danish,fitaly,french,french2,\
-  german,greek,hebrew,icelandic,italian,jisx6002/ja,jisx6004/ja,korean/ko_KR.eucKR,\
-  norwegian,portuguese,russian/ru_RU.KOI8-R,slovene,spanish,swedish,swissgerman,turkish,uk,latin1",
+"XVkbd.customizations: default,belgian,danish,fitaly,\
+  french,french2,german,greek,hebrew,icelandic,italian,\
+  jisx6002/ja_JP.eucJP,jisx6004/ja_JP.eucJP,korean/ko_KR.eucKR,\
+  norwegian,portuguese,russian/ru_RU.KOI8-R,slovene,spanish,\
+  swedish,swissgerman,turkish,uk,latin1,small,strip",
 "XVkbd*layout_panel*default.label: Default",
 "XVkbd*layout_panel*belgian.label: Belgian",
 "XVkbd*layout_panel*danish.label: Danish",
@@ -266,6 +268,8 @@
 "XVkbd*layout_panel*turkish.label: Turkish",
 "XVkbd*layout_panel*uk.label: United Kingdom",
 "XVkbd*layout_panel*latin1.label: Latin-1",
+"XVkbd*layout_panel*small.label: Small Keyboard",
+"XVkbd*layout_panel*strip.label: Key Strip",
 "XVkbd*Iconify.width: 20",
 "XVkbd*Iconify.shadowWidth: 0",
 "XVkbd*Iconify.resizable: false",
