@@ -24,6 +24,7 @@ struct appres_struct {
   String show_manual_command;
 
   String geometry;
+  Boolean inherit_geometry;
   Boolean debug;
   Boolean xtest;
   Boolean no_sync;
@@ -80,6 +81,11 @@ struct appres_struct {
   String shift_key_labels;
   String altgr_key_labels;
   String shift_altgr_key_labels;
+
+  String keypad_normal;
+  String keypad_shift;
+  String keypad_labels;
+
   String deadkeys;
   int altgr_keycode;
 
